==> haskell-x509-validation-1.6.8-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-validation
version: 1.6.8
id: x509-validation-1.6.8-FAm8cmmi9X74yypPP79R57
key: x509-validation-1.6.8-FAm8cmmi9X74yypPP79R57
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 Certificate and CRL validation
description:
    X.509 Certificate and CRL validation
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509.Validation
hidden-modules: Data.X509.Validation.Signature
                Data.X509.Validation.Fingerprint Data.X509.Validation.Cache
                Data.X509.Validation.Types
abi: 6343ad2eea12216e706d1f8850885e4a
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/x509-validation-1.6.8
library-dirs: /usr/lib/ghc-8.0.2/site-local/x509-validation-1.6.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/x509-validation-1.6.8
hs-libraries: HSx509-validation-1.6.8-FAm8cmmi9X74yypPP79R57
depends:
    asn1-encoding-0.9.5-IYQwkkfu141LtkpgWZ9ola
    asn1-types-0.3.2-9aXDFyarEaR4iFeC6pBR3x base-4.9.1.0
    byteable-0.1.1-2lU1pexQSLj1KbNO17UifQ bytestring-0.10.8.1
    containers-0.5.7.1 cryptonite-0.24-8CPx71TTAGL9kKBh2LMKdw
    data-default-class-0.1.2.0-N42RtcTZUUAlapzICmPz4
    hourglass-0.2.10-pnbvWmzfcY1rOFETQEmcY
    memory-0.14.6-8f3xLObLA3p67pVexclvQP
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 pem-0.2.2-CkEwei5500yF2642aAaOAi
    x509-1.7.1-5Bdd4fklHRL9Z7KJVZ3ngA
    x509-store-1.6.3-8peBKLGuhBC7RWmjxkElnb
haddock-interfaces: /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock
haddock-html: /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-validation-1.6.9-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-validation
version: 1.6.9
id: x509-validation-1.6.9-1qbFpHiwFdCDWBq3VHQyj6
key: x509-validation-1.6.9-1qbFpHiwFdCDWBq3VHQyj6
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 Certificate and CRL validation
description:
    X.509 Certificate and CRL validation
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509.Validation
hidden-modules: Data.X509.Validation.Signature
                Data.X509.Validation.Fingerprint Data.X509.Validation.Cache
                Data.X509.Validation.Types
abi: ddd55cf10fb4da7a4a7d8c1d45a4984e
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/x509-validation-1.6.9
library-dirs: /usr/lib/ghc-8.0.2/site-local/x509-validation-1.6.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/x509-validation-1.6.9
hs-libraries: HSx509-validation-1.6.9-1qbFpHiwFdCDWBq3VHQyj6
depends:
    asn1-encoding-0.9.5-IYQwkkfu141LtkpgWZ9ola
    asn1-types-0.3.2-9aXDFyarEaR4iFeC6pBR3x base-4.9.1.0
    byteable-0.1.1-2lU1pexQSLj1KbNO17UifQ bytestring-0.10.8.1
    containers-0.5.7.1 cryptonite-0.24-8CPx71TTAGL9kKBh2LMKdw
    data-default-class-0.1.2.0-N42RtcTZUUAlapzICmPz4
    hourglass-0.2.10-pnbvWmzfcY1rOFETQEmcY
    memory-0.14.6-8f3xLObLA3p67pVexclvQP
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 pem-0.2.2-CkEwei5500yF2642aAaOAi
    x509-1.7.2-8XP1uUZYB4C7XBwX9PCMZ2
    x509-store-1.6.5-A1HJpsd5Q1OJ9jINA8C88U
haddock-interfaces: /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock
haddock-html: /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
